@@ -104,7 +104,8 @@ char *url_double_encode(unsigned char *str)
     p2 = ret;
 
     while (*p1 != '\0') {
-	if ((*p1 >= 0x81 && *p1 <= 0xff)) {
+	if (*p1 <= 0x1f || *p1 >= 0x7f || *p1 == '\'' || *p1 == '+' ||
+            *p1 == '$' || *p1 == '%' || *p1 == '&' || *p1 == ';') {
 	    sprintf(p2, "%%25%02X", (int)*p1);
 	    p1++;
 	    p2 += 5;
@@ -135,7 +136,8 @@ char *url_encode(unsigned char *str)
     p2 = ret;
 
     while (*p1 != '\0') {
-	if ((*p1 >= 0x81 && *p1 <= 0xff)) {
+	if (*p1 <= 0x1f || *p1 >= 0x7f || *p1 == '\'' || *p1 == '+' ||
+            *p1 == '$' || *p1 == '%' || *p1 == '&' || *p1 == ';') {
 	    sprintf(p2, "%%%02X", (int)*p1);
 	    p1++;
 	    p2 += 3;
@@ -177,6 +179,7 @@ char *remove_quote(unsigned char *str)
 		break;
 	    }
 	    sprintf(p, "%%%02X", (int)*str);
+	    p += 3;
 	} else {
 	    *p = *str;
 	    p++; 
@@ -584,7 +587,6 @@ int convert_A(char *stago, char *elemname, char **attr, char *tagc)
 	sprintf(p, "'>");
 #endif
 
-
 /*
 		"<action type='soft1' task='gosub'"
 		" dest='device:home/goto?svc=Email&SUB=sendMsg'"
